@@ -36,7 +36,7 @@ static const R_CMethodDef Centries[] = {
 };
 
 static const R_CallMethodDef Callentries[] = {
-    {"Cagfit4",       (DL_FUNC) &agfit4,      12},
+    {"Cagfit4",       (DL_FUNC) &agfit4,      13},
     {"Cagmart3",      (DL_FUNC) &agmart3,      6},
     {"Cconcordance1", (DL_FUNC) &concordance1, 4}, 
     {"Cconcordance2", (DL_FUNC) &concordance2, 6}, 
@@ -44,10 +44,12 @@ static const R_CallMethodDef Callentries[] = {
     {"Ccoxcount2",    (DL_FUNC) &coxcount2,    4},
     {"Ccoxexact",     (DL_FUNC) &coxexact,     8},
     {"Ccoxfit6",      (DL_FUNC) &coxfit6,     12},
+    {"Cfinegray",     (DL_FUNC) &finegray,     6},
     {"Cpyears3b",     (DL_FUNC) &pyears3b,    10},
     {"Csurvfitci",    (DL_FUNC) &survfitci,   10},
     {"Csurvreg6",     (DL_FUNC) &survreg6,    15},
     {"Csurvreg7",     (DL_FUNC) &survreg7,    21},
+    {"Csurvsplit",    (DL_FUNC) &survsplit,    3},
     {"Ctmerge",       (DL_FUNC) &tmerge,       7},
     {NULL, NULL, 0}
 };
